@@ -1,5 +1,5 @@
 import click
-from freshenv import provision, view, start, remove, check
+from freshenv import provision, view, start, remove, check, clean
 
 
 @click.group()
@@ -12,4 +12,5 @@ cli.add_command(provision.provision)
 cli.add_command(view.view)
 cli.add_command(start.start)
 cli.add_command(remove.remove)
-cli.add_command(check.check)
\ No newline at end of file
+cli.add_command(check.check)
+cli.add_command(clean.clean)
\ No newline at end of file
